pytorch\_lightning\_spells package
==================================

.. automodule:: pytorch_lightning_spells
   :autosummary:
   :autosummary-no-nesting:
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   pytorch_lightning_spells.callbacks
   pytorch_lightning_spells.cutmix_utils
   pytorch_lightning_spells.loggers
   pytorch_lightning_spells.losses
   pytorch_lightning_spells.lr_schedulers
   pytorch_lightning_spells.metrics
   pytorch_lightning_spells.optimizers
   pytorch_lightning_spells.samplers
   pytorch_lightning_spells.snapmix_utils
   pytorch_lightning_spells.utils
